@@ -48,7 +48,7 @@ class EmulatorTestCase(test.CdistTestCase):
         handle, self.script = self.mkstemp(dir=self.temp_dir)
         os.close(handle)
         base_path = self.temp_dir
-        hostdir = cdist.str_hash(self.target_host)
+        hostdir = cdist.str_hash(self.target_host[0])
         host_base_path = os.path.join(base_path, hostdir)
 
         self.local = local.Local(
@@ -151,7 +151,7 @@ class EmulatorConflictingRequirementsTestCase(test.CdistTestCase):
         handle, self.script = self.mkstemp(dir=self.temp_dir)
         os.close(handle)
         base_path = self.temp_dir
-        hostdir = cdist.str_hash(self.target_host)
+        hostdir = cdist.str_hash(self.target_host[0])
         host_base_path = os.path.join(base_path, hostdir)
 
         self.local = local.Local(
@@ -241,7 +241,7 @@ class AutoRequireEmulatorTestCase(test.CdistTestCase):
     def setUp(self):
         self.temp_dir = self.mkdtemp()
         base_path = os.path.join(self.temp_dir, "out")
-        hostdir = cdist.str_hash(self.target_host)
+        hostdir = cdist.str_hash(self.target_host[0])
         host_base_path = os.path.join(base_path, hostdir)
 
         self.local = local.Local(
@@ -274,7 +274,7 @@ class OverrideTestCase(test.CdistTestCase):
         handle, self.script = self.mkstemp(dir=self.temp_dir)
         os.close(handle)
         base_path = self.temp_dir
-        hostdir = cdist.str_hash(self.target_host)
+        hostdir = cdist.str_hash(self.target_host[0])
         host_base_path = os.path.join(base_path, hostdir)
 
         self.local = local.Local(
@@ -315,7 +315,7 @@ class ArgumentsTestCase(test.CdistTestCase):
     def setUp(self):
         self.temp_dir = self.mkdtemp()
         base_path = self.temp_dir
-        hostdir = cdist.str_hash(self.target_host)
+        hostdir = cdist.str_hash(self.target_host[0])
         host_base_path = os.path.join(base_path, hostdir)
         handle, self.script = self.mkstemp(dir=self.temp_dir)
         os.close(handle)
@@ -440,7 +440,7 @@ class StdinTestCase(test.CdistTestCase):
 
         self.temp_dir = self.mkdtemp()
         base_path = os.path.join(self.temp_dir, "out")
-        hostdir = cdist.str_hash(self.target_host)
+        hostdir = cdist.str_hash(self.target_host[0])
         host_base_path = os.path.join(base_path, hostdir)
 
         self.local = local.Local(
